@@ -1,11 +1,15 @@
-from podfile import module
-from podfile import util
+from podfile.module import Module
+from podfile.common import Common
 
 
-class Target:
-    def __init__(self, target_info: dict):
+class Target(Common):
+    name: str = None
+    dependencies: list = None
+
+    def __init__(self, target_info: dict = None):
         if not target_info:
             return
+        super().parse_properties(target_info)
         self.name = target_info.get("name")
         dependencies = list()
         use_modular_headers: dict = target_info.get("use_modular_headers")
@@ -14,18 +18,17 @@ class Target:
             for_pods = use_modular_headers.get("for_pods")
         for var in target_info.get("dependencies"):
             lib_info: dict = var
-            mo = module.Module(lib_info)
+            mo = Module(lib_info)
             if for_pods:
                 if mo.name in for_pods:
                     mo.use_modular_header = True
             dependencies.append(mo)
         self.dependencies = dependencies
-        self.uses_frameworks = target_info.get("uses_frameworks")
 
-    def add_module(self, mod: module.Module):
+    def add_module(self, mod: Module):
         self.dependencies.append(mod)
 
-    def remove_module(self, mod: module.Module):
+    def remove_module(self, mod: Module):
         self.dependencies.remove(mod)
 
     def module_with_name(self, name: str):
@@ -35,8 +38,8 @@ class Target:
         return None
 
     def to_hash(self):
-        new_uses_frameworks = util.process_pod_keys(self.uses_frameworks)
-        target_info = {"name": self.name, "uses_frameworks": new_uses_frameworks}
+        target_info = super().to_hash()
+        target_info["name"] = self.name
         dependencies = []
         for_pods = []
         for dep in self.dependencies:
